@@ -2,25 +2,26 @@
 function(m,x,y,n.obs=NULL,digits=2)  {
  #a function to extract subsets of variables (a and b) from a correlation matrix m or data set m
   #and find the multiple correlation beta weights + R2 of the a set predicting the b set
-  #if there are NAs in the matrix, these are set to -999999 before the reordering and then set back to NA 
-   if(dim(m)[1]!=dim(m)[2]) {n.obs=dim(m)[1]
-                    m <- cor(m,use="pairwise") } else {m <- cov2cor(m)}
+  #seriously rewritten, March 24, 2009 to make much simpler
+  
   if(!is.matrix(m)) m <- as.matrix(m)
-  m[is.na(m)] <- -9999999
-    #first reorder the matrix to select the right variables
-         nm <- dim(m)[1]
-        t.mat <- matrix(0,ncol=nm,nrow=nm)
+  if(dim(m)[1]!=dim(m)[2]) {n.obs=dim(m)[1]
+                    C <- cov(m,use="pairwise")
+                    m <- cov2cor(C)}  else {
+                    C <- m
+                    m <- cov2cor(m)}
+                   
+ 
+        nm <- dim(m)[1]
         xy <- c(x,y)
-         numx <- length(x)
+        numx <- length(x)
      	numy <- length(y)
         nxy <- numx+numy
-        for (i in 1:nxy) {
-     	t.mat[i,xy[i]] <- 1 }
+     	a.matrix <- m[x,x]
+     	ac.matrix <- C[x,x]
+     	b.matrix <- m[x,y]
+     	bc.matrix <- C[x,y]
      	
-     	reorder <- t.mat %*% m %*% t(t.mat)
-     	reorder[abs(reorder)  > 100000] <- NA    #this allows us to use the matrix operations to reorder and pick
-     	a.matrix <- reorder[1:numx,1:numx]
-     	b.matrix <- reorder[1:numx,(numx+1):nxy]
      beta<- solve(a.matrix,b.matrix)       #solve the equation bY~aX
      	if (length(y) >1 ) { rownames(beta) <- colnames(m)[x]
      	 colnames(beta) <- colnames(m)[y]
@@ -29,6 +30,7 @@ function(m,x,y,n.obs=NULL,digits=2)  {
      	 names(beta) <- colnames(m)[x]
      	 names(R2) <- colnames(m)[y]}
      	if(!is.null(n.obs)) {k<- length(x)
+     	                     
      	                     uniq <- (1-smc(a.matrix))
      	                     se.beta <- list() 
      	                     for (i in 1:length(y)) {
@@ -38,6 +40,7 @@ function(m,x,y,n.obs=NULL,digits=2)  {
      	                     colnames(se) <- colnames(beta)
      	                     rownames(se) <- rownames(beta)
      	                     tvalue <- beta/se
+     	                     se <- t(t(se) * sqrt(diag(C)[y]))/sqrt(diag(ac.matrix))
      	                     
      	                prob <- 2*(1- pt(abs(tvalue),df))
      	                     SE2 <- 4*R2*(1-R2)^2*(df^2)/((n.obs^2-1)*(n.obs+3))
@@ -45,6 +48,9 @@ function(m,x,y,n.obs=NULL,digits=2)  {
      	                     F <- R2*df/(k*(1-R2))
      	                     pF <- 1 - pf(F,k,df)
      	                     shrunkenR2 <- 1-(1-R2)*(n.obs-1)/df    	                     }
+     	
+     	beta <-  t(t(beta) * sqrt(diag(C)[y]))/sqrt(diag(ac.matrix)) #this puts the betas into the raw units
+        
      	if(is.null(n.obs)) {mat.regress <- list(beta=round(beta,digits),R=round(sqrt(R2),digits),R2=round(R2,digits))} else {
      	              mat.regress <- list(beta=round(beta,digits),se=round(se,digits),t=round(tvalue,digits),Probability = round(prob,digits),R=round(sqrt(R2),digits),R2=round(R2,digits),shrunkenR2 = round(shrunkenR2,digits),seR2 = round(SE,digits),F=round(F,digits),probF= round(pF,digits+1),df=c(k,df))}
      	return(mat.regress)
