@@ -14,7 +14,7 @@ for (i in 1:length(cuts)) {
    trunc[observed< cuts[i],i]<- 0}
    
 d.mat<- data.frame(latent,observed,trunc)  #combine into a data frame
-pairs.panels(d.mat) 
+pairs.panels(d.mat,main="Phi coefficients for extreme cut point normal data") 
 trunc.cor<- cor(d.mat)                 #find the Pearson correlations
 freq <- mean(d.mat)                    #find the frequencies of scores
 
